@@ -11,11 +11,11 @@ URL::Normalize - Normalize/optimize URLs.
 
 =head1 VERSION
 
-Version 0.38
+Version 0.39
 
 =cut
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 =head1 SYNOPSIS
 
@@ -348,8 +348,9 @@ sub remove_directory_index {
 
 Sorts the URL's query parameters alphabetically.
 
-Uppercased parameters will be lowercased during sorting, and if there are
-multiple values for a parameter, the key/value-pairs will be sorted as well.
+Uppercased parameters will be lowercased DURING sorting, but the parameters will
+of course be in the original case after sorting. If there are multiple values
+for a parameter, the key/value-pairs will be sorted as well.
 
 Example:
 
